
'use strict';
{
  const globals = this;
  const django = globals.django || (globals.django = {});

  
  django.pluralidx = function(n) {
    const v = (n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);
    if (typeof v === 'boolean') {
      return v ? 1 : 0;
    } else {
      return v;
    }
  };
  

  /* gettext library */

  django.catalog = django.catalog || {};
  
  const newcatalog = {
    "(If left blank, owner will be admin)": "(If left blank, owner will be admin)",
    "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)": "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)",
    "(at least {placeholder} characters)": "(at least {placeholder} characters)",
    "(current notification)": "(pa\u0161reiz\u0113jais pazi\u0146ojums)",
    "(current version)": "(pa\u0161reiz\u0113j\u0101 versija)",
    "1 Year": "1 gads",
    "1 cell copied": "1 cell copied",
    "1 filter": "1 filtrs",
    "1 hidden property": "1 hidden property",
    "1 month ago": "Pirms 1 m\u0113ne\u0161a",
    "1 preset hidden property": "1 preset hidden property",
    "1 record selected": "1 record selected",
    "1 row is copied.": "1 row is copied.",
    "1 sort": "1 r\u0101d\u012b\u0161ana",
    "1 week ago": "Pirms 1 ned\u0113\u013cas",
    "3 days ago": "Pirms 3 dien\u0101m",
    "30 Days": "30 dienas",
    "7 Days": "7 dienas",
    "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
    "A file with the same name already exists in this folder.": "Datne ar t\u0101du pa\u0161u nosaukumu jau eksist\u0113 \u0161aj\u0101 map\u0113.",
    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
    "API Token": "API Token",
    "API token is copied to the clipboard.": "API token is copied to the clipboard.",
    "About": "Par",
    "About Us": "Par mums",
    "Abuse Content": "Abuse Content",
    "Abuse Reports": "Abuse Reports",
    "Abuse Type": "Abuse Type",
    "Abuse report added": "Abuse report added",
    "Accept": "Piekrist",
    "Accepted": "Pie\u0146emt",
    "Accepted at": "Accepted at",
    "Accepter": "Accepter",
    "Access Log": "Piek\u013cuves \u017eurn\u0101ls",
    "Accurate to minute": "Accurate to minute",
    "Action": "Action",
    "Actions": "Darb\u012bbas",
    "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email": "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email",
    "Activated": "Aktiviz\u0113t",
    "Activated Users": "Activated Users",
    "Active": "Akt\u012bvs",
    "Active Users": "Akt\u012bvie lietot\u0101ji",
    "Activities": "Aktivit\u0101tes",
    "Add": "Pievienot",
    "Add Admin": "Add Admin",
    "Add Library": "Pievienot bibliot\u0113ku",
    "Add Member": "Pievienot dal\u012bbnieku",
    "Add Organization": "Add Organization",
    "Add Terms and Conditions": "Pievienot noteikumus un nosac\u012bjumus",
    "Add User": "Add User",
    "Add Wiki": "Pievienot Wiki",
    "Add admin": "Pievienot administratoru",
    "Add auto expiration": "Pievienot autom\u0101tisko izbeig\u0161anos",
    "Add cover": "Add cover",
    "Add custom permission": "Add custom permission",
    "Add filter": "Pievienot filtru",
    "Add group": "Add group",
    "Add group member": "Add group member",
    "Add icon": "Add icon",
    "Add institution": "Pievienot instit\u016bciju",
    "Add members": "Pievienot dal\u012bbniekus",
    "Add new notification": "Pievienot jaunu pazi\u0146ojumu",
    "Add option": "Add option",
    "Add password protection": "Pievienot paroles aizsardz\u012bbu",
    "Add permission": "Add permission",
    "Add sort": "Pievienot r\u0101d\u012b\u0161anas opciju",
    "Add user": "Pievienot lietot\u0101ju",
    "Add view": "Add view",
    "Added": "Pievienots",
    "Added user {user}": "Added user {user}",
    "Admin": "Administrators",
    "Admin Login Logs": "Admin Login Logs",
    "Admin Operation Logs": "Admin Operation Logs",
    "Admin access": "Admin access",
    "Admins": "Administrators",
    "Advanced": "Advanced",
    "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.": "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.",
    "All": "Visi",
    "All Groups": "Visas grupas",
    "All Notifications": "Visi pazi\u0146ojumi",
    "All Public Links": "Visas publisk\u0101s saites",
    "All comments": "Visi koment\u0101ri",
    "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.",
    "An integer that is greater than 0 or equal to -2.": "An integer that is greater than 0 or equal to -2.",
    "An integer that is greater than or equal to 0.": "An integer that is greater than or equal to 0.",
    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "Iek\u0161\u0113jais linka apraksts",
    "And": "Un",
    "Anonymous User": "Anon\u012bms lietot\u0101js",
    "Another property has this property type": "Another property has this property type",
    "Another user is editing this file!": "Another user is editing this file!",
    "Anyone with the link": "Anyone with the link",
    "Are you sure to change group {placeholder} to department ?": "Are you sure to change group {placeholder} to department ?",
    "Are you sure to delete ": "Are you sure to delete ",
    "Are you sure to delete this comment?": "Vai tie\u0161\u0101m v\u0113laties dz\u0113st \u0161o koment\u0101ru?",
    "Are you sure to delete this reply?": "Vai tie\u0161\u0101m v\u0113laties dz\u0113st \u0161o atbildi?",
    "Are you sure to revoke access of user {placeholder} ?": "Are you sure to revoke access of user {placeholder} ?",
    "Are you sure you want to clear trash?": "Vai tie\u0161\u0101m v\u0113laties t\u012br\u012bt atkritni?",
    "Are you sure you want to delete": "Are you sure you want to delete",
    "Are you sure you want to delete %s ?": "Tie\u0161\u0101m dz\u0113st %s ?",
    "Are you sure you want to delete WebDAV password?": "Are you sure you want to delete WebDAV password?",
    "Are you sure you want to delete the notification ?": "Are you sure you want to delete the notification ?",
    "Are you sure you want to delete the selected share link(s) ?": "Are you sure you want to delete the selected share link(s) ?",
    "Are you sure you want to delete the selected user(s) ?": "Are you sure you want to delete the selected user(s) ?",
    "Are you sure you want to delete this page?": "Vai tie\u0161\u0101m v\u0113laties dz\u0113st \u0161o lapu?",
    "Are you sure you want to delete {placeholder} ?": "Are you sure you want to delete {placeholder} ?",
    "Are you sure you want to delete {placeholder} completely?": "Are you sure you want to delete {placeholder} completely?",
    "Are you sure you want to disconnect?": "Are you sure you want to disconnect?",
    "Are you sure you want to remove {placeholder} ?": "Are you sure you want to remove {placeholder} ?",
    "Are you sure you want to reset the password of {placeholder} ?": "Are you sure you want to reset the password of {placeholder} ?",
    "Are you sure you want to restore this library?": "Vai tie\u0161\u0101m v\u0113laties atjaunot \u0161\u014d bibliot\u0113ku?",
    "Are you sure you want to restore {placeholder}?": "Are you sure you want to restore {placeholder}?",
    "Are you sure you want to revoke the admin permission of {placeholder} ?": "Are you sure you want to revoke the admin permission of {placeholder} ?",
    "Are you sure you want to set {placeholder} as Admin?": "Are you sure you want to set {placeholder} as Admin?",
    "Are you sure you want to set {user_placeholder} inactive?": "Are you sure you want to set {user_placeholder} inactive?",
    "Are you sure you want to unlink this device?": "Vai tie\u0161\u0101m v\u0113laties no\u0146emt \u0161o ier\u012bci?",
    "At server": "At server",
    "Audio": "Audio",
    "Auth Token created": "Auth Token created",
    "Auth Token deleted": "Auth Token deleted",
    "Auto deletion": "Auto deletion",
    "Automatically delete files that are not modified within certain days:": "Automatically delete files that are not modified within certain days:",
    "Avatar": "Avatars",
    "Avatar updated": "Avatar updated",
    "Avatar:": "Avatars: ",
    "Back": "Atpaka\u013c",
    "Basic": "Basic",
    "Bell Icon": "Bell Icon",
    "Besides Write permission, user can also share the library.": "Besides Write permission, user can also share the library.",
    "Branding": "Branding",
    "Broken (please contact your administrator to fix this library)": "Boj\u0101ta (l\u016bdzu, sazinieties ar administratoru, lai salabotu \u0161o bibliot\u0113ku)",
    "By day": "By day",
    "By month": "By month",
    "By name ascending": "By name ascending",
    "By name descending": "By name descending",
    "By quarter": "By quarter",
    "By size ascending": "By size ascending",
    "By size descending": "By size descending",
    "By time ascending": "By time ascending",
    "By time descending": "By time descending",
    "By week": "By week",
    "By year": "By year",
    "Can not copy folder %(src)s to its subfolder %(des)s": "Can not copy folder %(src)s to its subfolder %(des)s",
    "Can not move folder %(src)s to its subfolder %(des)s": "Can not move folder %(src)s to its subfolder %(des)s",
    "Cancel": "Atcelt",
    "Cancel All": "Atcelt visus",
    "Cannot move parent page to child page": "Cannot move parent page to child page",
    "Capture information": "Capture information",
    "Capture time": "Capture time",
    "Card": "Kart\u012bte",
    "Certificate": "Certificate",
    "Change": "Main\u012bt",
    "Change Password": "Main\u012bt paroli",
    "Change Password of Library {placeholder}": "Main\u012bt bibliot\u0113kas paroli {placeholder}",
    "Change cover": "Change cover",
    "Change group to department": "Change group to department",
    "Change to department": "Change to department",
    "Changes": "Izmai\u0146as",
    "Checkbox": "Checkbox",
    "Choose date": "Choose date",
    "Clean": "T\u012br\u012bt",
    "Clean succeeded.": "Clean succeeded.",
    "Cleaned trash": "Cleaned trash",
    "Clear": "T\u012brs",
    "Clear Trash": "T\u012br\u012bt miskasti",
    "Clear files in trash and history\uff1a": "T\u012br\u012bt datnes atkritn\u0113 un v\u0113stur\u0113: ",
    "Clear selected": "Clear selected",
    "Clients": "Klienti",
    "Close": "Aizv\u0113rt",
    "Close (Esc)": "Aizv\u0113rt (Esc)",
    "Code": "V\u0113rt\u012bbu kods",
    "Collaborator": "Collaborator",
    "Collaborators": "Paticipanti",
    "Collapse all": "Collapse all",
    "Color space": "Color space",
    "Comment": "Koment\u0101rs",
    "Comment details": "Koment\u0101ra deta\u013ci",
    "Comments": "Koment\u0101ri",
    "Community Edition": "Community Edition",
    "Compressed": "Compressed",
    "Configure Seafile": "Configure Seafile",
    "Configure your Identity Provider": "Configure your Identity Provider",
    "Confirm": "P\u0101rbaud\u012bt",
    "Confirm Password": "Apstiprin\u0101t paroli",
    "Confirm password": "Confirm password",
    "Connect": "Connect",
    "Contact Email": "Kontaktpersonas e-pasts:",
    "Contact Email:": "Kontaktpersonas e-pasts:",
    "Contact Information": "Contact Information",
    "Contact information is required.": "Contact information is required.",
    "Content Scan Records": "Content Scan Records",
    "Convert & Export": "Convert & Export",
    "Convert Wiki": "Convert Wiki",
    "Convert to Markdown": "Convert to Markdown",
    "Convert to docx": "Convert to docx",
    "Convert to sdoc": "Convert to sdoc",
    "Convert with ONLYOFFICE": "Convert with ONLYOFFICE",
    "Converting, please wait...": "Converting, please wait...",
    "Copied": "Kop\u0113ts",
    "Copied link to clipboard": "Copied link to clipboard",
    "Copy": "Kop\u0113t",
    "Copy failed": "Copy failed",
    "Copy link": "Copy link",
    "Copy selected": "Copy selected",
    "Copy selected item(s) to:": "Kop\u0113t atlas\u012bto(s) ierakstu(s) uz:",
    "Copy the IdP's certificate and paste it here. The certificate format is as follows:": "Copy the IdP's certificate and paste it here. The certificate format is as follows:",
    "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.": "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.",
    "Copy {num} items": "Copy {num} items",
    "Copy {placeholder} to": "Copy {placeholder} to",
    "Copyright Infringement": "Copyright Infringement",
    "Count": "Skait\u012bt",
    "Cover": "Cover",
    "Create": "Izveidot",
    "Create At": "Izveidots",
    "Create Group": "Create Group",
    "Create Library": "Create Library",
    "Create Report": "Create Report",
    "Create a DNS TXT record to confirm the ownership of your Email Domain.": "Create a DNS TXT record to confirm the ownership of your Email Domain.",
    "Create a new tag": "Izveidot jaunu tagu",
    "Created": "Izveidoja",
    "Created At": "Izveidoja",
    "Created Files": "Created Files",
    "Created draft": "Created draft",
    "Created file": "Created file",
    "Created folder": "Created folder",
    "Created group {group_name}": "Created group {group_name}",
    "Created library": "Kr\u0101tuve izveidota",
    "Created library {library_name} with {owner} as its owner": "Created library {library_name} with {owner} as its owner",
    "Created time": "Izveido\u0161anas laiks",
    "Created {n} files": "Created {n} files",
    "Creator": "Autors",
    "Current Connected Devices": "Tagad savienotas ier\u012bces",
    "Current Library": "Pa\u0161reiz\u0113j\u0101 bibliot\u0113ka",
    "Current Path: ": "Pa\u0161reiz\u0113jais ce\u013c\u0161:",
    "Current Version": "Pa\u0161reiz\u0113j\u0101 versija",
    "Current page": "Current page",
    "Current password": "Current password",
    "Current password cannot be blank": "Pa\u0161reiz\u0113j\u0101 parole nedr\u012bkst b\u016bt tuk\u0161a",
    "Current path: ": "Atrodaties map\u0113: ",
    "Custom CSS": "Custom CSS",
    "Custom properties": "Custom properties",
    "Custom sharing permissions": "Custom sharing permissions",
    "Customize URL": "Customize URL",
    "DNS TXT Value": "DNS TXT Value",
    "Date": "Datums",
    "Date Invalid.": "Date Invalid.",
    "Day": "Day",
    "Default": "Noklus\u0113ts",
    "Delete": "Dz\u0113st",
    "Delete Account": "Dz\u0113st kontu",
    "Delete Department": "Delete Department",
    "Delete Expired Invitations": "Delete Expired Invitations",
    "Delete File": "Delete File",
    "Delete Folder": "Delete Folder",
    "Delete Group": "Dz\u0113st grupu",
    "Delete Institution": "Dz\u0113st instit\u016bciju",
    "Delete Library": "Dz\u0113st bibliot\u0113ku",
    "Delete Member": "Dz\u0113st biedru",
    "Delete Notification": "Dz\u0113st pazi\u0146ojumu",
    "Delete Organization": "Dz\u0113st organiz\u0101ciju",
    "Delete Password": "Delete Password",
    "Delete T&C": "Delete T&C",
    "Delete User": "Dz\u0113st lietot\u0101ju",
    "Delete Users": "Delete Users",
    "Delete WebDAV Password": "Delete WebDAV Password",
    "Delete file": "Delete file",
    "Delete files from this device the next time it comes online.": "Datnes tiks dz\u0113stas no ier\u012bces, n\u0101kamreiz non\u0101kot tie\u0161saist\u0113.",
    "Delete folder": "Delete folder",
    "Delete group": "Delete group",
    "Delete page": "Delete page",
    "Delete property": "Delete property",
    "Delete selected": "Delete selected",
    "Delete share links": "Delete share links",
    "Deleted": "Dz\u0113sts",
    "Deleted Libraries": "Dz\u0113st\u0101s bibliot\u0113kas",
    "Deleted Time": "Dz\u0113\u0161anas laiks",
    "Deleted directories": "Dz\u0113st\u0101s mapes",
    "Deleted draft": "Deleted draft",
    "Deleted file": "Deleted file",
    "Deleted files": "Dz\u0113st datnes",
    "Deleted folder": "Deleted folder",
    "Deleted group {group_name}": "Deleted group {group_name}",
    "Deleted library": "Dz\u0113st\u0101s bibliot\u0113kas",
    "Deleted library {library_name}": "Deleted library {library_name}",
    "Deleted option": "Deleted option",
    "Deleted user %s": "Deleted user %s",
    "Deleted user {user}": "Deleted user {user}",
    "Department renamed": "Department renamed",
    "Departments": "Departments",
    "Description": "Apraksts",
    "Description is required": "Nepiecie\u0161ams apraksts",
    "Desktop": "Darbvirsma",
    "Detail": "Deta\u013cas",
    "Details": "Deta\u013cas",
    "Device": "Ier\u012bce",
    "Device Name": "Ier\u012bces nosaukums",
    "Device make": "Device make",
    "Device model": "Device model",
    "Devices": "Ier\u012bces",
    "Dimensions": "Dimensions",
    "Direct download link": "Direct download link",
    "Direct download link is copied to the clipboard.": "Direct download link is copied to the clipboard.",
    "Disable Two-Factor Authentication": "Atsp\u0113jot divfaktoru autentifik\u0101cija",
    "Disconnect": "Disconnect",
    "Discussion": "Diskusija",
    "Display files": "Display files",
    "Do not automatically delete files": "Do not automatically delete files",
    "Do you really want to turn off extended properties? Existing properties will all be deleted.": "Do you really want to turn off extended properties? Existing properties will all be deleted.",
    "Document": "Document",
    "Document conversion failed.": "Document conversion failed.",
    "Document keywords": "Document keywords",
    "Domain verified": "Domain verified",
    "Don't ignore": "Don't ignore",
    "Don't keep history": "Negrab\u0101t v\u0113sturi",
    "Don't replace": "Neaizst\u0101t",
    "Don't send emails": "Don't send emails",
    "Done": "Done",
    "Down": "Apak\u0161\u0101",
    "Download": "Lejupl\u0101d\u0113t",
    "Download and upload": "Download and upload",
    "Duplicate": "Duplicate",
    "Duplicate page": "Duplicate page",
    "Edit": "Main\u012bt",
    "Edit format settings": "Edit format settings",
    "Edit labels": "Edit labels",
    "Edit metadata properties": "Edit metadata properties",
    "Edit multiple select": "Edit multiple select",
    "Edit on cloud and download": "Edit on cloud and download",
    "Edit on cloud only": "Edit on cloud only",
    "Edit permission": "Edit permission",
    "Edit single select": "Edit single select",
    "Edit succeeded": "Redi\u0123\u0113\u0161ana izdev\u0101s",
    "Edit succeeded.": "Edit succeeded.",
    "Email": "E-pasts",
    "Email Domain": "Email Domain",
    "Email Notification": "Email Notification",
    "Email is invalid.": "Email is invalid.",
    "Email notification updated": "Email notification updated",
    "Emails": "Emails",
    "Emails, separated by ','": "Emails, separated by ','",
    "Emojis": "Emojis",
    "Empty": "Tuk\u0161s",
    "Enable Two-Factor Authentication": "Aktiviz\u0113t divfaktoru autentifik\u0101cija",
    "Enable extended properties": "Enable extended properties",
    "Enable face recognition to identify people in your photos.": "Enable face recognition to identify people in your photos.",
    "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.": "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.",
    "Enable two factor authentication": "Enable two factor authentication",
    "Enable users to share libraries to any groups in the system.": "Enable users to share libraries to any groups in the system.",
    "Encrypt": "\u0160ifr\u0113t",
    "Encrypted library": "\u0160ifr\u0113ta bibliot\u0113ka",
    "End date": "End date",
    "Enter characters to start searching": "Enter characters to start searching",
    "Error": "K\u013c\u016bda",
    "Errors": "K\u013c\u016bdas",
    "European": "European",
    "Exact date": "Exact date",
    "Exit Institution Admin": "Exit Institution Admin",
    "Exit Organization Admin": "Exit Organization Admin",
    "Exit System Admin": "Iziet no administratora loga",
    "Expand all": "Expand all",
    "Expiration": "Izbeig\u0161an\u0101s",
    "Expiration days": "Expiration days",
    "Expiration time": "Expiration time",
    "Expired": "Beigties",
    "Expired at": "Expired at",
    "Export": "Export",
    "Export Excel": "Eksport\u0113t Excel",
    "Export as docx": "Export as docx",
    "Export as zip": "Export as zip",
    "Export tags": "Export tags",
    "Exporting": "Exporting",
    "Exporting...": "Exporting...",
    "Exposure time": "Exposure time",
    "Extended properties": "Extended properties",
    "Extension Prompts": "Extension Prompts",
    "Extensions of text files that can be online previewed, each suffix is separated by a comma.": "Extensions of text files that can be online previewed, each suffix is separated by a comma.",
    "Extract file detail": "Extract file detail",
    "Extract file details": "Extract file details",
    "F number": "F number",
    "Face recognition": "Face recognition",
    "Failed": "Neizdev\u0101s",
    "Failed imported options": "Failed imported options",
    "Failed to convert {name}.": "Failed to convert {name}.",
    "Failed to copy %(name)s": "K\u013c\u016bda kop\u0113jot %(name)s.",
    "Failed to copy %(name)s and %(amount)s other item(s).": "Failed to copy %(name)s and %(amount)s other item(s).",
    "Failed to copy %(name)s.": "Failed to copy %(name)s.",
    "Failed to copy files to another library.": "Failed to copy files to another library.",
    "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Failed to delete %(virus_file) from library %(library): %(error_msg)",
    "Failed to delete property": "Failed to delete property",
    "Failed to delete records": "Failed to delete records",
    "Failed to delete {name}": "Failed to delete {name}",
    "Failed to delete {name} and {n} other items.": "Failed to delete {name} and {n} other items.",
    "Failed to delete {name}.": "Failed to delete {name}.",
    "Failed to download. The total size of the files exceeded the limit.": "Failed to download. The total size of the files exceeded the limit.",
    "Failed to duplicate page": "Failed to duplicate page",
    "Failed to export. Please check whether the size of table attachments exceeds the limit.": "Failed to export. Please check whether the size of table attachments exceeds the limit.",
    "Failed to extract file details": "Failed to extract file details",
    "Failed to generate description": "Failed to generate description",
    "Failed to ignore %(virus_file) from library %(library): %(error_msg)": "Failed to ignore %(virus_file) from library %(library): %(error_msg)",
    "Failed to insert property": "Failed to insert property",
    "Failed to modify filter": "Failed to modify filter",
    "Failed to modify group": "Failed to modify group",
    "Failed to modify hidden properties": "Failed to modify hidden properties",
    "Failed to modify people name": "Failed to modify people name",
    "Failed to modify property data": "Failed to modify property data",
    "Failed to modify property order": "Failed to modify property order",
    "Failed to modify records": "Failed to modify records",
    "Failed to modify sort": "Failed to modify sort",
    "Failed to move %(name)s and %(amount)s other item(s).": "Failed to move %(name)s and %(amount)s other item(s).",
    "Failed to move %(name)s.": "Failed to move %(name)s.",
    "Failed to move files to another library.": "Failed to move files to another library.",
    "Failed to move {name}.": "Failed to move {name}.",
    "Failed to rename property": "Failed to rename property",
    "Failed to restore records": "Failed to restore records",
    "Failed to restore {name}": "Failed to restore {name}",
    "Failed to restore {name} and {n} other items": "Failed to restore {name} and {n} other items",
    "Failed to save": "Failed to save",
    "Failed to send to {email_placeholder}: {errorMsg_placeholder}": "Failed to send to {email_placeholder}: {errorMsg_placeholder}",
    "Failed to unshare {name}": "Failed to unshare {name}",
    "Failed to upload {file_name}.": "Failed to upload {file_name}.",
    "Failed. Please check the network.": "Neizdev\u0101s. L\u016bdzu p\u0101rbaudiet t\u012bkla piesl\u0113gumu.",
    "Favorites": "Favor\u012bti",
    "File": "Datne",
    "File Access": "File Access",
    "File Operations": "File Operations",
    "File Update": "File Update",
    "File Upload": "Datni aug\u0161upl\u0101d\u0113t",
    "File Uploading...": "Datni aug\u0161upl\u0101d\u0113...",
    "File already exists.": "File already exists.",
    "File collaborators": "File collaborators",
    "File details": "File details",
    "File download is disabled: the share link traffic of owner is used up.": "File download is disabled: the share link traffic of owner is used up.",
    "File expire time": "File expire time",
    "File extension white list": "File extension white list",
    "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.": "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.",
    "File extensions can only be {placeholder}.": "File extensions can only be {placeholder}.",
    "File is locked by others.": "File is locked by others.",
    "File name": "File name",
    "File owner": "File owner",
    "File reviewer": "File reviewer",
    "File size is too large.": "File size is too large.",
    "File status": "File status",
    "File too large": "File too large",
    "File type": "File type",
    "Files": "Datnes",
    "Files and folders": "Files and folders",
    "Filter": "Filtr\u0113t",
    "Filters": "Filters",
    "Find a tag": "Find a tag",
    "Find modifiers": "Find modifiers",
    "Focal length": "Focal length",
    "Folder": "Mape",
    "Folder Permission": "Mapes ties\u012bbas",
    "Folder does not exist.": "Folder does not exist.",
    "Folders": "Mapes",
    "Force user to change password when account is newly added or reset by admin": "Force user to change password when account is newly added or reset by admin",
    "Force user to use a strong password when sign up or change password.": "Force user to use a strong password when sign up or change password.",
    "Format": "Format",
    "Freeze Document": "Freeze Document",
    "Freeze user account when failed login attempts exceed limit.": "Freeze user account when failed login attempts exceed limit.",
    "Frozen by {name}": "Frozen by {name}",
    "Full screen": "Pilna ekr\u0101na re\u017e\u012bms",
    "Gallery": "Gallery",
    "General information": "General information",
    "Generate": "Izveidot",
    "Generate Link": "Generate Link",
    "Generate description": "Generate description",
    "Generate links in batch": "Generate links in batch",
    "Generate share link": "Generate share link",
    "Germany Russia etc": "Germany Russia etc",
    "Global Address Book": "Global Address Book",
    "Greater than or equal to {minDays_placeholder} days": "Greater than or equal to {minDays_placeholder} days",
    "Grid view": "Grid view",
    "Group": "Grupa",
    "Group Permission": "Grupas ties\u012bbas",
    "Group Shares": "Group Shares",
    "Group by": "Group by",
    "Group members": "Group members",
    "Grouped by 1 property": "Grouped by 1 property",
    "Groups": "Grupas",
    "Guest": "Viesis",
    "Handled": "Apstr\u0101d\u0101ts",
    "Help": "Pal\u012bdz\u012bba",
    "Hide": "Sl\u0113pt",
    "Hide all": "Sl\u0113pt visus stulpeli",
    "Hide properties": "Hide properties",
    "History": "V\u0113sture",
    "History Setting": "V\u0113stures iestat\u012bjumi",
    "History Versions": "History Versions",
    "IP": "IP adrese",
    "ISO": "ISO",
    "If notifications have not been read within one hour, they will be sent to your mailbox.": "If notifications have not been read within one hour, they will be sent to your mailbox.",
    "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.",
    "Ignore": "Ignore",
    "Ignored": "Ignored",
    "Import Users": "Import Users",
    "Import members": "Import members",
    "Import members from a .xlsx file": "Import members from a .xlsx file",
    "Import options": "Import options",
    "Import sdoc": "Import sdoc",
    "Import tags": "Import tags",
    "Import users": "Import\u0113t lietot\u0101jus",
    "Import users from a .xlsx file": "Import users from a .xlsx file",
    "In progress": "In progress",
    "In review": "In review",
    "Inactive": "Neakt\u012bvs",
    "Info": " Inform\u0101cija",
    "Institution Admin": "Institution Admin",
    "Institutions": "Instit\u016bcija",
    "Internal Link": "Internal Link",
    "Internal Server Error": "Iek\u0161\u0113j\u0101 servera k\u013c\u016bda",
    "Internal link has been copied to clipboard": "Kop\u0113t iek\u0161\u0113jo linku",
    "Invalid destination path": "Neder\u012bgs m\u0113r\u0137a ce\u013c\u0161",
    "Invalid filename.": "Invalid filename.",
    "Invalid filter": "Nepareiza filtr\u0113\u0161anas opcija",
    "Invalid month, should be yyyymm.": "Invalid month, should be yyyymm.",
    "Invalid regular expression": "Invalid regular expression",
    "Invisible": "Invisible",
    "Invitations": "Iel\u016bgumi",
    "Invite Guest": "Invite Guest",
    "Invite Time": "Uzaicin\u0101\u0161anas laiks",
    "Invite users": "Invite users",
    "Invited at": "Invited at",
    "Inviter": "Uzaicin\u0101t\u0101js",
    "Is expired": "Is expired",
    "It is required.": "Nepiecie\u0161ams.",
    "It may take some time, please wait.": "It may take some time, please wait.",
    "Keep full history": "Glab\u0101t pilnu v\u0113sturi",
    "Keep sharing": "Keep sharing",
    "LDAP": "LDAP",
    "LDAP(imported)": "LDAP(import\u0113ts)",
    "Label": "Label",
    "Label Current State": "Label Current State",
    "Labels": "Labels",
    "Language": "Valoda",
    "Language Setting": "Valodas iestat\u012bjumi",
    "Last Access": "P\u0113d\u0113j\u0101 piek\u013cuve",
    "Last Login": "P\u0113d\u0113j\u0101 pieteik\u0161an\u0101s",
    "Last Update": "Atjaunots",
    "Last modification": "P\u0113d\u0113j\u0101s izmai\u0146as",
    "Last modified by": "Last modified by",
    "Last modified time": "Last modified time",
    "Last modifier": "Last modifier",
    "Leave": "Leave",
    "Leave Group": "Leave Group",
    "Leave Share": "At\u013cauja koplietojumam",
    "Leave group": "Atst\u0101t grupu",
    "Leave this page? The system may not save your changes.": "Leave this page? The system may not save your changes.",
    "Less than or equal to {maxDays_placeholder} days": "Less than or equal to {maxDays_placeholder} days",
    "Libraries": "Kr\u0101tuves",
    "Library": "Kr\u0101tuve",
    "Library Type": "Bibliot\u0113kas tips",
    "Library does not exist": "Bibliot\u0113ka nepast\u0101v",
    "Limits": "Ierobe\u017eojumi",
    "Link": "Saite",
    "Link has been copied to clipboard": "Link has been copied to clipboard",
    "Linked Devices": "Saist\u012bt\u0101s ier\u012bces",
    "Links": "Saites",
    "List view": "List view",
    "List your account in global address book, so that others can find you by typing your name.": "List your account in global address book, so that others can find you by typing your name.",
    "Load all": "Load all",
    "Loading": "Loading",
    "Loading...": "Iel\u0101de... ",
    "Location": "Lok\u0101cija",
    "Lock": "Blo\u0137\u0113t",
    "Log out": "Iziet",
    "Login": "Login",
    "Login ID": "Login ID",
    "Logo updated": "Logo updated",
    "Logs": "\u017durn\u0101ls",
    "Long text": "Long text",
    "Manage group members": "Manage group members",
    "Manage members": "Manage members",
    "Mark all as read": "P\u0101rbaud\u012bt visas k\u0101 las\u012btas",
    "Mark all read": "Atz\u012bm\u0113t visas izlas\u012btas",
    "Mark as resolved": "Iz\u012bm\u0113t k\u0101 atrisin\u0101tu",
    "Max": "Max",
    "Max number of members": "Max number of members",
    "Member": "Dal\u012bbnieks",
    "Members": "Biedri",
    "Message": "Zi\u0146a",
    "Message (optional):": "Zi\u0146a (nav oblig\u0101ti)",
    "Migrate User": "Migrate User",
    "Mobile": "Mobilais",
    "Modification Details": "Detaliz\u0113ta inform\u0101cija par izmai\u0146\u0101m",
    "Modified": "Main\u012bts",
    "Modified by": "Modified by",
    "Modified by:": "Modified by:",
    "Modified files": "Main\u012bt\u0101s datnes",
    "Modifier": "Main\u012bjis",
    "Modify": "Modify",
    "Modify includes modify file, move/rename file and folder": "Modify includes modify file, move/rename file and folder",
    "Modify name": "Modify name",
    "Month": "Month",
    "Month:": "M\u0113nes\u012b: ",
    "Monthly User Traffic": "Monthly User Traffic",
    "More": "Vair\u0101k",
    "More operations": "Vair\u0101k darb\u012bbas",
    "Move": "P\u0101rvietot",
    "Move selected item(s) to:": "P\u0101rvietot atlas\u012bto ierakstu(s) uz:",
    "Move {num} items": "Move {num} items",
    "Move {placeholder} to": "Move {placeholder} to",
    "Moved file": "Moved file",
    "Moved folder": "Moved folder",
    "Multiple select": "Multiple select",
    "My Libraries": "Manas bibliot\u0113kas",
    "My Wikis": "My Wikis",
    "Name": "Nosaukums",
    "Name already exists": "Name already exists",
    "Name cannot be double dots": "Name cannot be double dots",
    "Name cannot be empty": "Name cannot be empty",
    "Name cannot contain backslash": "Name cannot contain backslash",
    "Name cannot contain backtick": "Name cannot contain backtick",
    "Name cannot contain curly braces": "Name cannot contain curly braces",
    "Name cannot contain dots": "Name cannot contain dots",
    "Name cannot contain slash": "Name cannot contain slash",
    "Name is required": "Nepiecie\u0161ams nosaukums",
    "Name is required.": "Nepiecie\u0161ams nosaukums.",
    "Name or ID": "Name or ID",
    "Name should be string": "Name should be string",
    "Name should not include '/'.": "Name should not include '/'.",
    "Name updated": "Name updated",
    "Name(optional)": "V\u0101rds (nav oblig\u0101ti)",
    "Network error": "Network error",
    "New": "Nou\u017e\u0123\u012bt",
    "New Department": "New Department",
    "New Department Library": "New Department Library",
    "New Excel File": "Jauna Excel datne",
    "New File": "Jauna datne",
    "New Folder": "Jauna mape",
    "New Group": "Jauna grupa",
    "New Library": "Jauna kr\u0101tuve",
    "New Markdown File": "New Markdown File",
    "New Password": "Jauna parole",
    "New Password Again": "Jaun\u0101 parole atk\u0101rtoti",
    "New PowerPoint File": "Jauna PowerPoint datne",
    "New SeaDoc File": "New SeaDoc File",
    "New Sub-department": "New Sub-department",
    "New Word File": "New Word File",
    "New directories": "Jaunas mapes",
    "New file name": "New file name",
    "New files": "Jauna datne",
    "New folder name": "New folder name",
    "New page": "N\u0101kam\u0101 lapa",
    "New password": "Jauna parole",
    "New password cannot be the same as old password": "New password cannot be the same as old password",
    "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.",
    "New password is too short": "Jaun\u0101 parole par \u012bsu",
    "New passwords don't match": "Jaun\u0101 parole nesakr\u012bt",
    "New view": "New view",
    "Next": "N\u0101kamais",
    "Next (Right arrow key)": "N\u0101kamais (bulti\u0146a pa labi)",
    "Next modification": "N\u0101kam\u0101s izmai\u0146as",
    "No Admin login logs": "No Admin login logs",
    "No Admin operation logs": "No Admin operation logs",
    "No Wikis": "No Wikis",
    "No changes": "Nav izmai\u0146\u0101m",
    "No collaborators": "No collaborators",
    "No collaborators available": "No collaborators available",
    "No comment yet.": "Nav koment\u0101ru.",
    "No connected devices": "Nav savienotas ier\u012bces",
    "No deleted libraries": "No deleted libraries",
    "No favorites": "No favorites",
    "No file": "No file",
    "No file access logs": "No file access logs",
    "No file update logs": "No file update logs",
    "No filters": "Nav pievienotas filtr\u0113\u0161anas opcijas",
    "No folders shared": "No folders shared",
    "No groupings applied to this view.": "No groupings applied to this view.",
    "No groups": "Nav grupas",
    "No guest invitations": "No guest invitations",
    "No invitations": "No invitations",
    "No libraries": "Bibliot\u0113kas nav",
    "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.": "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.",
    "No libraries have been shared with you": "No libraries have been shared with you",
    "No libraries have been shared with you from other servers.": "No libraries have been shared with you from other servers.",
    "No libraries shared": "No libraries shared",
    "No libraries shared with this group": "No libraries shared with this group",
    "No linked devices": "No linked devices",
    "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.",
    "No login logs": "No login logs",
    "No members": "Nav biedru",
    "No more activities": "No more activities",
    "No notifications": "No notifications",
    "No option": "No option",
    "No options": "No options",
    "No options available": "No options available",
    "No permission logs": "No permission logs",
    "No properties available to be hidden": "No properties available to be hidden",
    "No record": "No record",
    "No result": "Nav rezult\u0101ta",
    "No results": "Nav atrast\u0101s rezult\u0101tas",
    "No results matching": "No results matching",
    "No share links": "No share links",
    "No sorts": "Nav r\u0101d\u012b\u0161anas opcijas",
    "No sync errors": "Nav sinhroniz\u0101cijas k\u013c\u016bdas",
    "No tags": "Nav atz\u012bm\u0113m",
    "No terms and conditions": "No terms and conditions",
    "No upload links": "No upload links",
    "No version history": "No version history",
    "None": "Neviens",
    "Not allow user to clean library trash": "Not allow user to clean library trash",
    "Not allow user to create encrypted libraries": "Not allow user to create encrypted libraries",
    "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.",
    "Notification Detail": "Pazi\u0146ojuma deta\u013cas",
    "Notifications": "Pazi\u0146ojums",
    "Notifications of file changes": "Notifications of file changes",
    "Number": "Number",
    "Number of days ago": "Number of days ago",
    "Number of days from now": "Number of days from now",
    "Number of days that keep user sign in.": "Number of days that keep user sign in.",
    "Number of groups": "Grupu skaits",
    "Number of links": "Number of links",
    "Number of members": "Dal\u012bbnieku skaits",
    "Off": "Izsl\u0113gt",
    "Old Password": "Vec\u0101 parole",
    "Old Wikis": "Old Wikis",
    "On": "Iesl\u0113gt",
    "One month ago": "One month ago",
    "One month from now": "One month from now",
    "One week ago": "One week ago",
    "One week from now": "One week from now",
    "Online Preview": "Online Preview",
    "Online Read-Only": "Online Read-Only",
    "Online Read-Only folder": "Online Read-Only folder",
    "Online Read-Only library": "Online Read-Only library",
    "Online Read-Write": "Online Read-Write",
    "Online Read-Write folder": "Online Read-Write folder",
    "Online Read-Write library": "Online Read-Write library",
    "Online view is not applicable to this file format": "Online view is not applicable to this file format",
    "Only Show": "Only Show",
    "Only files": "Only files",
    "Only folders": "Only folders",
    "Only keep a period of history:": "Glab\u0101t v\u0113sturi par periodu:",
    "Only pictures": "Only pictures",
    "Only videos": "Only videos",
    "Open file": "Open file",
    "Open file in new tab": "Open file in new tab",
    "Open folder": "Open folder",
    "Open folder in new tab": "Open folder in new tab",
    "Open in new tab": "Open in new tab",
    "Open parent folder": "Atv\u0113rt vec\u0101ka mapes",
    "Open via Client": "Atv\u0113rt ar klientu",
    "Operation": "Darb\u012bbas",
    "Operation succeeded.": "Darb\u012bba veiksm\u012bga",
    "Operations": "Darb\u012bbas",
    "Optional": "Optional",
    "Options imported": "Options imported",
    "Or": "Vai",
    "Organization": "Organiz\u0101cija",
    "Organization Admin": "Organiz\u0101cijas administrators",
    "Organizations": "Organiz\u0101cijas",
    "Original path": "Original path",
    "Other": "Other",
    "Other Libraries": "Cita bibliot\u0113ka",
    "Others": "Others",
    "Out of quota.": "P\u0101rsniegts apjoms",
    "Outdated": "Outdated",
    "Outline": "Izskait\u013cis",
    "Owned Libraries": "Owned Libraries",
    "Owner": "\u012apa\u0161nieks",
    "Owner can use admin panel in an organization, must be a new account.": "Owner can use admin panel in an organization, must be a new account.",
    "Packaging...": "Pakoju...",
    "Page name": "Page name",
    "Pages": "Lapas",
    "Parent folder": "Parent folder",
    "Password": "Parole",
    "Password again": "Atk\u0101rtot paroli",
    "Password cannot be blank": "Parole nevar b\u016bt tuk\u0161a",
    "Password is too short": "Parole par \u012bsu",
    "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols": "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols",
    "Password removed": "Password removed",
    "Password reset": "Password reset",
    "Password set": "Password set",
    "Password strength": "Password strength",
    "Password updated": "Password updated",
    "Passwords do not match.": "Passwords do not match.",
    "Passwords don't match": "Paroles nesakr\u012bt",
    "Path": "Path",
    "Per 4 hours": "Per 4 hours",
    "Per day": "Per day",
    "Per hour": "Per hour",
    "Per week": "Per week",
    "Permission": "Ties\u012bbas",
    "Permission denied": "Pieeja liegta",
    "Permission denied. Please try {placeholder-left}login again.{placeholder-right}": "Permission denied. Please try {placeholder-left}login again.{placeholder-right}",
    "Permission name": "Permission name",
    "Person image": "Person image",
    "Picture": "Picture",
    "Pictures and videos": "Pictures and videos",
    "Platform": "Platforma",
    "Please check the network.": "L\u016bdzu p\u0101rbaudiet t\u012bkla piesl\u0113gumu",
    "Please choose a .xlsx file.": "Please choose a .xlsx file.",
    "Please choose an image file.": "Please choose an image file.",
    "Please enter 1 or more character": "L\u016bdzu, ievadiet 1 vai vair\u0101k rakstz\u012bmes",
    "Please enter a new password": "L\u016bdzu, ievadiet jaunu paroli",
    "Please enter a non-negative integer": "L\u016bdzu, ievadiet nepiecie\u0161am\u0101s dienas",
    "Please enter a password.": "Please enter a password.",
    "Please enter a positive integer": "Please enter a positive integer",
    "Please enter an integer bigger than 1 as number of links.": "Please enter an integer bigger than 1 as number of links.",
    "Please enter an integer not bigger than {max_number} as number of links.": "Please enter an integer not bigger than {max_number} as number of links.",
    "Please enter days": "L\u016bdzu, ievadiet dienas",
    "Please enter password": "L\u016bdzu, ievadiet paroli.",
    "Please enter the new password again": "L\u016bdzu, ievadiet jauno paroli atk\u0101rtoti",
    "Please enter the old password": "L\u016bdzu, ievadiet veco paroli",
    "Please enter the password again": "L\u016bdzu ievad\u012bt paroli v\u0113lreiz",
    "Please input at least an email.": "L\u016bdzu, ievadiet vismaz e-pastu.",
    "Please select a file": "Please select a file",
    "Please select a library to share.": "Please select a library to share.",
    "Please select an expiration time": "Please select an expiration time",
    "Please upload no more than {maxFiles} files at a time.": "Please upload no more than {maxFiles} files at a time.",
    "Preset hide properties": "Preset hide properties",
    "Preview and download": "P\u0101rskat\u012bt un lejupiel\u0101d\u0113t",
    "Preview online": "Preview online",
    "Preview only": "P\u0101rskat\u012bt tikai",
    "Previous": "Iepriek\u0161\u0113jais",
    "Previous (Left arrow key)": "Iepriek\u0161\u0113jais (bulti\u0146a pa kreisi)",
    "Print": "Noprint\u0113t",
    "Professional Edition": "Profesion\u0101lais izdevums",
    "Profile": "Profils",
    "Profile Setting": "Profila iestat\u012bjumi",
    "Properties": "Properties",
    "Property name": "Property name",
    "Publish": "Publ\u0113t",
    "Publish Wiki": "Publish Wiki",
    "Published": "Public\u0113ts",
    "Quota": "Quota",
    "Quota is invalid.": "Quota is invalid.",
    "Rate": "Rate",
    "Read-Only": "Tikai las\u012bt",
    "Read-Only folder": "Read-Only folder",
    "Read-Only library": "Tikai las\u012bt bibliot\u0113ka",
    "Read-Write": "Las\u012bt-Rakst\u012bt",
    "Read-Write folder": "Read-Write folder",
    "Read-Write library": "Las\u012bt-Rakst\u012bt bibliot\u0113ka",
    "Really want to delete this group?": "Really want to delete this group?",
    "Really want to delete your account?": "Tie\u0161\u0101m dz\u0113st kontu?",
    "Really want to leave this group?": "Really want to leave this group?",
    "Recognizing portraits. Please refresh the page later.": "Recognizing portraits. Please refresh the page later.",
    "Refresh": "Atjaunot",
    "Remove": "Aizv\u0101kt",
    "Rename": "P\u0101rsaukt",
    "Rename Department": "Rename Department",
    "Rename File": "P\u0101rsaukt datni",
    "Rename Folder": "P\u0101rsaukt mapi",
    "Rename Group": "Rename Group",
    "Rename Wiki": "Rename Wiki",
    "Rename file": "Rename file",
    "Rename folder": "Rename folder",
    "Rename group to": "Rename group to",
    "Rename property": "Rename property",
    "Renamed file": "Renamed file",
    "Renamed folder": "Renamed folder",
    "Renamed library": "Renamed library",
    "Renamed or Moved files": "P\u0101rsaukt vai p\u0101rvietot datnes",
    "Renaming {name} failed": "Renaming {name} failed",
    "Replace": "Aizst\u0101t",
    "Replace file {filename}?": "Aizst\u0101t datni {filename}?",
    "Replacing it will overwrite its content.": "Aizst\u0101jot tiks p\u0101rrakst\u012bts datnes saturs.",
    "Report Abuse": "Report Abuse",
    "Reporter": "Reporter",
    "Reports": "Reports",
    "Required at least three letters.": "Required at least three letters.",
    "Reset": "Reset",
    "Reset Password": "Atiestat\u012bt paroli",
    "Reset WebDAV Password": "Reset WebDAV Password",
    "Reset library password": "Reset library password",
    "ResetPwd": "Atstat\u012bt",
    "Resetting user's password, please wait for a moment.": "Resetting user's password, please wait for a moment.",
    "Resolved comments": "Pabeigti koment\u0101ri",
    "Restore": "Atjaunot",
    "Restore Library": "Atjaunot bibliot\u0113ku",
    "Restored file": "Restored file",
    "Restored folder": "Restored folder",
    "Restored library": "Restored library",
    "Restored {name}": "Restored {name}",
    "Restored {name} and {n} other items": "Restored {name} and {n} other items",
    "Resubmit": "P\u0101rbaud\u012bt v\u0113lreiz",
    "Result": "Rezult\u0101ts",
    "Revoke Access": "Revoke Access",
    "Revoke Admin": "Anul\u0113t administratoru",
    "Role": "Loma",
    "SAML config": "SAML config",
    "SAML config updated": "SAML config updated",
    "Save": "Saglab\u0101t",
    "Save Selected Items": "Save Selected Items",
    "Save to:": "Save to:",
    "Saving...": "Saglab\u0101...",
    "Scan the QR code to view the shared content directly": "Scan the QR code to view the shared content directly",
    "SeaTable integration": "SeaTable integration",
    "Seafile": "Seafile",
    "Search": "Mekl\u0113t",
    "Search Groups": "Search Groups",
    "Search Libraries": "Search Libraries",
    "Search Organizations": "Search Organizations",
    "Search Users": "Search Users",
    "Search collaborator": "Mekl\u0113t kolabor\u0101tora",
    "Search collaborators": "Search collaborators",
    "Search department": "Mekl\u0113t departamentu",
    "Search files": "Search files",
    "Search files in this library": "Mekl\u0113t datnes bibliot\u0113k\u0101",
    "Search groups": "Mekl\u0113t grupas",
    "Search groups by name": "Search groups by name",
    "Search libraries by name or ID": "Search libraries by name or ID",
    "Search libraries by owner": "Search libraries by owner",
    "Search option": "Mekl\u0113t opciju",
    "Search organizations": "Search organizations",
    "Search property": "Search property",
    "Search users": "Search users",
    "Search users...": "Mekl\u0113t lietot\u0101jus...",
    "Searching...": "Mekl\u0113...",
    "Select": "Atlas\u012bt",
    "Select File": "Select File",
    "Select a department": "Select a department",
    "Select a user": "Select a user",
    "Select a user as admin": "Select a user as admin",
    "Select all": "Select all",
    "Select an option": "Izv\u0113lieties opciju",
    "Select collaborators": "Select collaborators",
    "Select libraries to share": "Atlas\u012bt koplieto\u0161anas bibliot\u0113kas ",
    "Select option(s)": "Izv\u0113lieties opciju(us)",
    "Select up to 50 files": "Select up to 50 files",
    "Send": "S\u016bt\u012bt",
    "Send activation Email after user registration.": "Send activation Email after user registration.",
    "Send to:": "S\u016bt\u012bt uz:",
    "Sending new password...": "Sending new password...",
    "Sending...": "S\u016bta...",
    "Server Version: ": "Servera versija: ",
    "Set Admin": "Iestat\u012bt administratoru",
    "Set Contact Email": "Set Contact Email",
    "Set Download Rate Limit": "Set Download Rate Limit",
    "Set Login ID": "Set Login ID",
    "Set Name": "Set Name",
    "Set Password": "Set Password",
    "Set Quota": "Iestat\u012bt kvotas",
    "Set Upload Rate Limit": "Set Upload Rate Limit",
    "Set WebDAV Password": "Set WebDAV Password",
    "Set max number of members": "Set max number of members",
    "Set password": "Set password",
    "Set permission": "Iestat\u012bt at\u013caujas",
    "Set permission of {placeholder}": "Set permission of {placeholder}",
    "Set to current": "Iestat\u012bt pa\u0161reiz\u0113jo",
    "Set user contact email": "Set user contact email",
    "Set user default quota": "Set user default quota",
    "Set user name": "Set user name",
    "Set user quota": "Set user quota",
    "Setting library history is disabled by Admin.": "Setting library history is disabled by Admin.",
    "Settings": "Iestat\u012bjumi",
    "Share": "Dal\u012bties",
    "Share Admin": "Koplieto\u0161an\u0101",
    "Share From": "Koplietojums no ",
    "Share Link": "Dal\u012bties saiti",
    "Share Links": "Koplieto\u0161anas saites",
    "Share To": "Dal\u012bts ar",
    "Share To:": "Share To:",
    "Share link download": "Share link download",
    "Share link is copied to the clipboard.": "Share link is copied to the clipboard.",
    "Share link upload": "Share link upload",
    "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.": "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.",
    "Share to group": "Koplietot grupai",
    "Share to other server": "Share to other server",
    "Share to user": "Koplietot lietot\u0101jam",
    "Shared By": "Dal\u0101s",
    "Shared Libraries": "Shared Libraries",
    "Shared Links": "Koplieto\u0161anas saites",
    "Shared by: ": "Dal\u0101s: ",
    "Shared with all": "Koplietot visiem",
    "Shared with me": "Man koplietot\u0101s ",
    "Show": "R\u0101d\u012bt",
    "Show Codes": "R\u0101d\u012bt kodu",
    "Show all": "Par\u0101d\u012bt visus stulpeli",
    "Show changes": "Show changes",
    "Side Nav Menu": "S\u0101nu navig\u0101cijas izv\u0113lne",
    "Single select": "Single select",
    "Site name used in email sending": "Site name used in email sending",
    "Site title shown in a browser tab": "Site title shown in a browser tab",
    "Size": "Izm\u0113rs ",
    "Sort": "R\u0101d\u012bt p\u0113c",
    "Sort ascending": "Sort ascending",
    "Sort descending": "Sort descending",
    "Space Used": "Izlietots",
    "Space Used / Quota": "Izlietots / Kvota",
    "Specific people with email address": "Specific people with email address",
    "Specific users in the team": "Specific users in the team",
    "Star": "Zvaigzne",
    "Start date": "Start date",
    "Status": "Statuss",
    "Status: enabled": "Status: enabled",
    "Storage": "Kr\u0101tuve",
    "Storage Backend": "Storage Backend",
    "Storage Used": "Kr\u0101tuves izlietojums",
    "Style": "Stilijs",
    "Submit": "Pielietot",
    "Success": "Veiksm\u012bgi",
    "Successfully added label(s) for library {placeholder}": "Successfully added label(s) for library {placeholder}",
    "Successfully change the group": "Successfully change the group",
    "Successfully changed library password.": "Bibliot\u0113kas parole veiksm\u012bgi nomain\u012bta.",
    "Successfully cleared trash.": "Successfully cleared trash.",
    "Successfully converted the file.": "Successfully converted the file.",
    "Successfully copied %(name)s and %(amount)s other items.": "Veiksm\u012bgi kop\u0113ts %(name)s un %(amount)s citi ieraksti.",
    "Successfully copied %(name)s and 1 other item.": "Veiksm\u012bgi kop\u0113ts %(name)s un 1 cits ieraksts.",
    "Successfully copied %(name)s.": "Veiksm\u012bgi kop\u0113ts %(name)s.",
    "Successfully copied files to another library.": "Successfully copied files to another library.",
    "Successfully deleted 1 item": "Veiksm\u012bgi izdz\u0113sts 1 objekts",
    "Successfully deleted 1 item.": "Veiksm\u012bgi izdz\u0113sts 1 objekts",
    "Successfully deleted 1 share link": "Successfully deleted 1 share link",
    "Successfully deleted 1 user.": "Successfully deleted 1 user.",
    "Successfully deleted {name}": "Successfully deleted {name}",
    "Successfully deleted {name} and {n} other items": "Successfully deleted {name} and {n} other items",
    "Successfully deleted {name} and {n} other items.": "Successfully deleted {name} and {n} other items.",
    "Successfully deleted {name}.": "Successfully deleted {name}.",
    "Successfully deleted {number_placeholder} share links": "Successfully deleted {number_placeholder} share links",
    "Successfully deleted {user_number_placeholder} users.": "Successfully deleted {user_number_placeholder} users.",
    "Successfully edited labels.": "Successfully edited labels.",
    "Successfully invited %(email) and %(num) other people.": "Successfully invited %(email) and %(num) other people.",
    "Successfully invited %(email).": "Successfully invited %(email).",
    "Successfully moved %(name)s and %(amount)s other items.": "Veiksm\u012bgi p\u0101rs\u016bt\u012bts %(name)s un %(amount)s citi ieraksti.",
    "Successfully moved %(name)s and 1 other item.": "Veiksm\u012bgi p\u0101rs\u016bt\u012bts %(name)s un 1 cits ieraksts",
    "Successfully moved %(name)s.": " Veiksm\u012bgi p\u0101rs\u016bt\u012bts %(name)s.",
    "Successfully moved files to another library.": "Successfully moved files to another library.",
    "Successfully moved {name}.": "Successfully moved {name}.",
    "Successfully restored the library {library_name}.": "Successfully restored the library {library_name}.",
    "Successfully restored the library.": "Successfully restored the library.",
    "Successfully restored.": "Successfully restored.",
    "Successfully revoke the admin permission of %s": "Veiksm\u012bgi anul\u0113t administratora at\u013caujas %s",
    "Successfully revoked access of user {placeholder}.": "Successfully revoked access of user {placeholder}.",
    "Successfully revoked the admin permission of {placeholder}.": "Successfully revoked the admin permission of {placeholder}.",
    "Successfully saved": "Successfully saved",
    "Successfully sent to {placeholder}": "Veiksm\u012bgi nos\u016bt\u012bts {placeholder}",
    "Successfully set %s as admin.": "Veiksm\u012bgi iestat\u012bts %s, k\u0101 administrators.",
    "Successfully set it.": "Successfully set it.",
    "Successfully set library history.": "Veiksm\u012bgi iestat\u012bta bibliot\u0113kas v\u0113sture.",
    "Successfully starred {library_name_placeholder}.": "Successfully starred {library_name_placeholder}.",
    "Successfully transferred the group.": "Veiksm\u012bgi p\u0101rs\u016bt\u012bta grupa",
    "Successfully transferred the library.": "Bibliot\u0113ka tika veiksm\u012bgi p\u0101rs\u016bt\u012bta.",
    "Successfully unlinked the device.": "Successfully unlinked the device.",
    "Successfully unshared {name}": "Successfully unshared {name}",
    "Successfully unstarred {library_name_placeholder}.": "Successfully unstarred {library_name_placeholder}.",
    "Suggestion": "Sugestija",
    "Switch sort mode": "Switch sort mode",
    "Switch to plain text editor": "P\u0101rsl\u0113gt uz vienk\u0101r\u0161u teksta redaktoru",
    "Switch to rich text editor": "P\u0101rsl\u0113gt uz pl\u0101no teksta redaktoru",
    "Switch view mode": "Switch view mode",
    "Sync": "Sync",
    "Sync Download": "Sync Download",
    "Sync Upload": "Sync Upload",
    "System": "Sist\u0113ma",
    "System Admin": "Administratora logs",
    "System Info": "Sist\u0113mas info",
    "System settings updated": "System settings updated",
    "Table": "Tabula",
    "Tag not found": "Taga nav atrasts",
    "Tagged Files": "Tagged Files",
    "Tags": "Atz\u012bmes",
    "Team name": "Team name",
    "Template": "\u0160ablons",
    "Terms": "Terms",
    "Terms and Conditions": "Noteikumi un nosac\u012bjumi",
    "Text": "Teksts",
    "Text is required.": "Text is required.",
    "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved": "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved",
    "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved": "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved",
    "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.": "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.",
    "The file is too large. Allowed maximum size is 1MB.": "The file is too large. Allowed maximum size is 1MB.",
    "The imported options are invalid": "The imported options are invalid",
    "The least number of characters a share/upload link password should include.": "The least number of characters a share/upload link password should include.",
    "The least number of characters an encrypted library password should include.": "The least number of characters an encrypted library password should include.",
    "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols",
    "The link is copied to the clipboard.": "The link is copied to the clipboard.",
    "The list of added, deleted and modified files will be sent to your mailbox.": "The list of added, deleted and modified files will be sent to your mailbox.",
    "The maximum number of failed login attempts before showing CAPTCHA.": "The maximum number of failed login attempts before showing CAPTCHA.",
    "The name \"{name}\" is already taken. Please choose a different name.": "The name \"{name}\" is already taken. Please choose a different name.",
    "The next month": "The next month",
    "The next numbers of days": "The next numbers of days",
    "The next week": "The next week",
    "The next year": "The next year",
    "The owner of this library has run out of space.": "Bibliot\u0113kas \u012bpa\u0161niekam ir aptr\u016bkusies vieta.",
    "The password is too short.": "The password is too short.",
    "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.": "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.",
    "The password will be kept in the server for only 1 hour.": "Parole tiks glab\u0101ta uz servera tikai 1 stundu.",
    "The past month": "The past month",
    "The past numbers of days": "The past numbers of days",
    "The past week": "The past week",
    "The past year": "The past year",
    "There is another option with this name": "There is another option with this name",
    "There is another property with this name": "There is another property with this name",
    "There is no information to display.": "There is no information to display.",
    "This file has been updated.": "Fails ir atjaunots.",
    "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).": "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This folder has no content at this time.": "This folder has no content at this time.",
    "This is a special group representing a department.": "This is a special group representing a department.",
    "This is required": "This is required",
    "This library has been set to read-only by admin and cannot be updated.": "This library has been set to read-only by admin and cannot be updated.",
    "This library has been shared to {user_amount} user(s) and {group_amount} group(s).": "This library has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This library is password protected": "Bibliot\u0113ka ir aizsarg\u0101ta ar paroli",
    "This month": "This month",
    "This operation will not be reverted. Please think twice!": "Neatgriezeniska darb\u012bba, izdom\u0101jiet k\u0101rt\u012bgi!",
    "This property can not be deleted": "This property can not be deleted",
    "This property does not support sorting": "This property does not support sorting",
    "This property is not editable": "This property is not editable",
    "This user has not created or joined any groups": "\u0160is lietot\u0101js nav izveidots vai pievienots nevienai grupai",
    "This week": "This week",
    "This year": "This year",
    "Thumbnail": "Thumbnail",
    "Time": "Laiks",
    "Tip: -2 means no limit.": "Tip: -2 means no limit.",
    "Tip: 0 means default limit": "Padoms. 0 ir noklus\u0113tais limits",
    "Tip: a snapshot will be generated after modification, which records the library state after the modification.": "Tip: a snapshot will be generated after modification, which records the library state after the modification.",
    "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.": "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.",
    "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.": "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.",
    "Tip: you can search by keyword in name or ID.": "Tip: you can search by keyword in name or ID.",
    "Tip: you can search by keyword in name.": "Tip: you can search by keyword in name.",
    "Today": "Today",
    "Token": "Token",
    "Token:": "Token:",
    "Tomorrow": "Tomorrow",
    "Too many requests": "Too many requests",
    "Total Devices": "Kop\u0101 ier\u012bces",
    "Total Storage": "Total Storage",
    "Total Users": "Kopskaits",
    "Traffic": "Datpl\u016bsma",
    "Transfer": "P\u0101rs\u016bt\u012bt",
    "Transfer Group": "Transfer Group",
    "Transfer Group {placeholder} to": "Transfer Group {placeholder} to",
    "Transfer Library": "P\u0101rs\u016bt\u012bt bibliot\u0113ku",
    "Transfer Library {library_name}": "Transfer Library {library_name}",
    "Transfer group to": "Transfer group to",
    "Transfer to department": "Transfer to department",
    "Transfer to user": "Transfer to user",
    "Transferred group {group_name} from {user_from} to {user_to}": "Transferred group {group_name} from {user_from} to {user_to}",
    "Transferred library {library_name} from {user_from} to {user_to}": "Transferred library {library_name} from {user_from} to {user_to}",
    "Trash": "Miskaste",
    "Turn off": "Turn off",
    "Turn off extended properties": "Turn off extended properties",
    "Turn on extensible properties and views to experience a new way of managing files": "Turn on extensible properties and views to experience a new way of managing files",
    "Two-Factor Authentication": "Divfaktoru autentifik\u0101cija",
    "Type": "Tips",
    "Type characters to start search": "Type characters to start search",
    "URL is copied to the clipboard": "URL is copied to the clipboard",
    "URL is required": "URL is required",
    "US": "US",
    "Undo": "Undo",
    "Unfreeze Document": "Unfreeze Document",
    "Unhandled": "Unhandled",
    "Unknown": "Nezin\u0101ms",
    "Unlink": "Atsaist\u012bt",
    "Unlink device": "Atsaist\u012bt\u0101s ier\u012bces",
    "Unlock": "Atblo\u0137\u0113t",
    "Unresolved comments": "Neapstr\u0101d\u0101ti koment\u0101ri",
    "Unselect": "Unselect",
    "Unshare": "Liegt pieeju",
    "Unshare Library": "Atcelt pieejas kr\u0101tuvei",
    "Unstar": "Bez zvaigzn\u012btes",
    "Untitled": "Untitled",
    "Unwatch File Changes": "Unwatch File Changes",
    "Up": "Aug\u0161\u0101",
    "Update": "Atjaunot",
    "Update Terms and Conditions": "Atjaunot noteikumus un nosac\u012bjumus",
    "Update password": "Update password",
    "Update succeeded.": "Update succeeded.",
    "Updated draft": "Updated draft",
    "Updated file": "Updated file",
    "Upgrade to Pro Edition": "jaunin\u0101\u0161ana uz profesion\u0101lo izdevumu",
    "Upload": "Aug\u0161upl\u0101d\u0113t",
    "Upload Files": "Aug\u0161upl\u0101d\u0113t datnes",
    "Upload Folder": "Aug\u0161upl\u0101d\u0113t mapi",
    "Upload Link": "Aug\u0161upiel\u0101d\u0113t saiti",
    "Upload Links": "Aug\u0161upiel\u0101d\u0113t saites",
    "Upload file": "Aug\u0161upl\u0101d\u0113t datni",
    "Upload license": "Upload license",
    "Upload link is copied to the clipboard.": "Upload link is copied to the clipboard.",
    "Uploading...": "Uploading...",
    "Use custom CSS": "Use custom CSS",
    "Use information from your Identity Provider to configure Seafile": "Use information from your Identity Provider to configure Seafile",
    "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.": "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.",
    "Use these values to configure your Identity Provider": "Use these values to configure your Identity Provider",
    "Used:": "Lietots:",
    "User": "Lietot\u0101js",
    "User Permission": "Lietot\u0101ja ties\u012bbas",
    "User Shares": "User Shares",
    "User Storage": "User Storage",
    "User can not see this folder.": "User can not see this folder.",
    "User can only view files online via browser. Files can't be downloaded.": "User can only view files online via browser. Files can't be downloaded.",
    "User can read, download and sync files.": "User can read, download and sync files.",
    "User can read, write, upload, download and sync files.": "User can read, write, upload, download and sync files.",
    "User can view and edit file online via browser. Files can't be downloaded.": "User can view and edit file online via browser. Files can't be downloaded.",
    "User info updated": "User info updated",
    "User migrate from {user_from} to {user_to}": "User migrate from {user_from} to {user_to}",
    "User not found": "User not found",
    "User {user_link} has added you to {group_link}": "User {user_link} has added you to {group_link}",
    "Username:": "Lietot\u0101jv\u0101rds:",
    "Users": "Lietot\u0101ji",
    "Verified": "Verified",
    "Verify": "P\u0101rbaud\u012bt",
    "Verify Domain": "Verify Domain",
    "Version": "Versija",
    "Version Number": "Versijas numurs",
    "Version Number is required.": "Version Number is required.",
    "Version Number must be a number.": "Version Number must be a number.",
    "Video": "Video",
    "View": "Skat\u012bt",
    "View Link": "View Link",
    "View Related Snapshot": "View Related Snapshot",
    "View Snapshot": "Skat\u012bt momentuz\u0146\u0113mumu",
    "View profile and more": "Skat\u012bt profilu",
    "Views": "Views",
    "Virus": "Virus",
    "Virus File": "V\u012brusa datne",
    "Virus Scan": "V\u012brusu sken\u0113\u0161ana",
    "Visit count": "Visit count",
    "Visit old version page": "Visit old version page",
    "Visited": "Visited",
    "Visits": "Apmekl\u0113jumi",
    "Watch File Changes": "Watch File Changes",
    "Web API Auth Token": "Web API Auth Token",
    "Web Download": "Web Download",
    "Web Upload": "Web Upload",
    "WebDAV Access": "WebDAV Access",
    "WebDAV password:": "WebDAV password:",
    "WebDAV username:": "WebDAV username:",
    "Wiki custom URL deleted": "Wiki custom URL deleted",
    "Wiki owner": "Wiki owner",
    "Wiki published": "Wiki published",
    "Wikis": "Wikis",
    "Wrong password": "K\u013c\u016bdaina parole",
    "Year": "Year",
    "Yesterday": "Yesterday",
    "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Varat pievienot lietot\u0101ju k\u0101 viesi, kuram netiks at\u013cauts izveidot bibliot\u0113kas vai grupas.",
    "You can create files quickly": "You can create files quickly",
    "You can enter multiple emails. An invitation link will be sent to each of them.": "You can enter multiple emails. An invitation link will be sent to each of them.",
    "You can use this field at login.": "You can use this field at login.",
    "You do not have permission": "You do not have permission",
    "You don't have any favorite items yet": "You don't have any favorite items yet",
    "You don't have any share links": "You don't have any share links",
    "You don't have any upload links": "You don't have any upload links",
    "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.",
    "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.": "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.",
    "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.": "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.",
    "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.": "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.",
    "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.": "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.",
    "You have not shared any folders": "You have not shared any folders",
    "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.": "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.",
    "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".": "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".",
    "Your notifications will be sent to this email.": "Your notifications will be sent to this email.",
    "ZIP": "ZIP",
    "all": "visi",
    "all members": "visi dal\u012bbnieki",
    "contains": "Atbilst",
    "days": "dienas",
    "deleted": "deleted",
    "deleted option": "deleted option",
    "details": "details",
    "does not contain": "Nekatram atbilst",
    "email is required": "email is required",
    "freezed": "freezed",
    "has all of...": "has all of...",
    "has any of...": "has any of...",
    "has none of...": "has none of...",
    "icon": "ikona",
    "in all libraries": "in all libraries",
    "include the current user": "Izmantojiet pa\u0161reiz\u0113jo lietot\u0101ju",
    "is": "Liekas",
    "is after...": "is after...",
    "is any of...": "is any of...",
    "is before...": "is before...",
    "is current user's ID": "Liekas pa\u0161reiz\u0113j\u0101 lietot\u0101ja ID",
    "is empty": "Liekas tuk\u0161a",
    "is exactly...": "is exactly...",
    "is none of...": "is none of...",
    "is not": "Nekatram liekas",
    "is not empty": "Nekatram liekas tuk\u0161a",
    "is on or after...": "is on or after...",
    "is on or before...": "is on or before...",
    "is within...": "is within...",
    "items": "items",
    "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}": "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}",
    "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}": "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}",
    "locked": "blo\u0137\u0113ts",
    "locked by {name}": "locked by {name}",
    "mm": "mm",
    "name": "v\u0101rds",
    "not set": "not set",
    "only show {placeholder}": "only show {placeholder}",
    "s": "s",
    "selected": "selected",
    "show more": "show more",
    "sorts": "R\u0101d\u012b\u0161anas opcijas",
    "starred": "zvaig\u017e\u0146otas",
    "successfully added user %s.": "successfully added user %s.",
    "successfully sent email to %s.": "successfully sent email to %s.",
    "unstarred": "bez zvaigz\u012bnes",
    "xxx cells copied": "xxx cells copied",
    "xxx cells selected": "xxx cells selected",
    "xxx record": "xxx record",
    "xxx records": "xxx records",
    "xxx records selected": "xxx records selected",
    "xxx rows are copied.": "xxx rows are copied.",
    "you can also press \u2190 ": "var spiest ar\u012b  \u2190 ",
    "you can also press \u2192": "you can also press \u2192",
    "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
    "{file} and {n} other files": "{file} and {n} other files",
    "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
    "{number_placeholder} / Page": "{number_placeholder} / Page",
    "{placeholder} Access Log": "{placeholder} Access Log",
    "{placeholder} Folder Permission": "{placeholder} Mapes at\u013caujas",
    "{placeholder} History Setting": "{placeholder} V\u0113stures iestat\u012b\u0161ana",
    "{placeholder} Modification History": "{placeholder} Modification History",
    "{placeholder} Share Admin": "{placeholder} Share Admin",
    "{placeholder} Snapshot": "{placeholder} Snapshot",
    "{placeholder} Trash": "{placeholder} Trash",
    "{placeholder} Wiki Trash": "{placeholder} Wiki Trash",
    "{share_from} has cancelled the sharing of folder {repo_name}.": "{share_from} has cancelled the sharing of folder {repo_name}.",
    "{share_from} has cancelled the sharing of library {repo_name}.": "{share_from} has cancelled the sharing of library {repo_name}.",
    "{share_from} has changed the permission of folder {repo_link} to {permission}.": "{share_from} has changed the permission of folder {repo_link} to {permission}.",
    "{share_from} has changed the permission of library {repo_link} to {permission}.": "{share_from} has changed the permission of library {repo_link} to {permission}.",
    "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} has shared a folder named {repo_link} to group {group_link}.",
    "{share_from} has shared a folder named {repo_link} to you.": "{share_from} has shared a folder named {repo_link} to you.",
    "{share_from} has shared a library named {repo_link} to group {group_link}.": "{share_from} has shared a library named {repo_link} to group {group_link}.",
    "{share_from} has shared a library named {repo_link} to you.": "{share_from} has shared a library named {repo_link} to you.",
    "{uploaded_files_num}/{all_files_num} Files": "{uploaded_files_num}/{all_files_num} Files",
    "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.",
    "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} created file {fileName} in library {libraryName}.": "{user} created file {fileName} in library {libraryName}.",
    "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} created folder {folderName} in library {libraryName}.": "{user} created folder {folderName} in library {libraryName}.",
    "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} deleted file {fileName} in library {libraryName}.": "{user} deleted file {fileName} in library {libraryName}.",
    "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} deleted folder {folderName} in library {libraryName}.": "{user} deleted folder {folderName} in library {libraryName}.",
    "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} moved file {fileName} in library {libraryName}.": "{user} moved file {fileName} in library {libraryName}.",
    "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} moved folder {folderName} in library {libraryName}.": "{user} moved folder {folderName} in library {libraryName}.",
    "{user} renamed file {oldFileName} {fileName} in library {libraryName}.": "{user} renamed file {oldFileName} {fileName} in library {libraryName}.",
    "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.": "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.",
    "{user} restored file {fileName} in library {libraryName}.": "{user} restored file {fileName} in library {libraryName}.",
    "{user} restored folder {folderName} in library {libraryName}.": "{user} restored folder {folderName} in library {libraryName}.",
    "{user} updated file {fileName} in library {libraryName}.": "{user} updated file {fileName} in library {libraryName}."
  };
  for (const key in newcatalog) {
    django.catalog[key] = newcatalog[key];
  }
  

  if (!django.jsi18n_initialized) {
    django.gettext = function(msgid) {
      const value = django.catalog[msgid];
      if (typeof value === 'undefined') {
        return msgid;
      } else {
        return (typeof value === 'string') ? value : value[0];
      }
    };

    django.ngettext = function(singular, plural, count) {
      const value = django.catalog[singular];
      if (typeof value === 'undefined') {
        return (count == 1) ? singular : plural;
      } else {
        return value.constructor === Array ? value[django.pluralidx(count)] : value;
      }
    };

    django.gettext_noop = function(msgid) { return msgid; };

    django.pgettext = function(context, msgid) {
      let value = django.gettext(context + '\x04' + msgid);
      if (value.includes('\x04')) {
        value = msgid;
      }
      return value;
    };

    django.npgettext = function(context, singular, plural, count) {
      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
      if (value.includes('\x04')) {
        value = django.ngettext(singular, plural, count);
      }
      return value;
    };

    django.interpolate = function(fmt, obj, named) {
      if (named) {
        return fmt.replace(/%\(\w+\)s/g, function(match){return String(obj[match.slice(2,-2)])});
      } else {
        return fmt.replace(/%s/g, function(match){return String(obj.shift())});
      }
    };


    /* formatting library */

    django.formats = {
    "DATETIME_FORMAT": "Y. \\g\\a\\d\\a j. F, H:i",
    "DATETIME_INPUT_FORMATS": [
      "%Y-%m-%d %H:%M:%S",
      "%Y-%m-%d %H:%M:%S.%f",
      "%Y-%m-%d %H:%M",
      "%d.%m.%Y %H:%M:%S",
      "%d.%m.%Y %H:%M:%S.%f",
      "%d.%m.%Y %H:%M",
      "%d.%m.%y %H:%M:%S",
      "%d.%m.%y %H:%M:%S.%f",
      "%d.%m.%y %H:%M",
      "%d.%m.%y %H.%M.%S",
      "%d.%m.%y %H.%M.%S.%f",
      "%d.%m.%y %H.%M",
      "%Y-%m-%d"
    ],
    "DATE_FORMAT": "Y. \\g\\a\\d\\a j. F",
    "DATE_INPUT_FORMATS": [
      "%Y-%m-%d",
      "%d.%m.%Y",
      "%d.%m.%y"
    ],
    "DECIMAL_SEPARATOR": ",",
    "FIRST_DAY_OF_WEEK": 1,
    "MONTH_DAY_FORMAT": "j. F",
    "NUMBER_GROUPING": 3,
    "SHORT_DATETIME_FORMAT": "j.m.Y H:i",
    "SHORT_DATE_FORMAT": "j.m.Y",
    "THOUSAND_SEPARATOR": "\u00a0",
    "TIME_FORMAT": "H:i",
    "TIME_INPUT_FORMATS": [
      "%H:%M:%S",
      "%H:%M:%S.%f",
      "%H:%M",
      "%H.%M.%S",
      "%H.%M.%S.%f",
      "%H.%M"
    ],
    "YEAR_MONTH_FORMAT": "Y. \\g. F"
  };

    django.get_format = function(format_type) {
      const value = django.formats[format_type];
      if (typeof value === 'undefined') {
        return format_type;
      } else {
        return value;
      }
    };

    /* add to global namespace */
    globals.pluralidx = django.pluralidx;
    globals.gettext = django.gettext;
    globals.ngettext = django.ngettext;
    globals.gettext_noop = django.gettext_noop;
    globals.pgettext = django.pgettext;
    globals.npgettext = django.npgettext;
    globals.interpolate = django.interpolate;
    globals.get_format = django.get_format;

    django.jsi18n_initialized = true;
  }
};

